<?php if (wfOnboardingController::shouldShowNewTour(wfOnboardingController::TOUR_LOGIN_SECURITY)): ?>
<div class="wordfence-vue-wrapper" data-base-component="LoginSecurityNewTour"></div>
<?php endif; ?>